# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msg.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='msg.proto',
  package='',
  serialized_pb=_b('\n\tmsg.proto\";\n\x0bKDelPayload\x12\x0f\n\x07\x63luster\x18\x01 \x02(\t\x12\x0e\n\x06\x62ucket\x18\x02 \x02(\t\x12\x0b\n\x03key\x18\x03 \x02(\t')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_KDELPAYLOAD = _descriptor.Descriptor(
  name='KDelPayload',
  full_name='KDelPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='KDelPayload.cluster', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='KDelPayload.bucket', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key', full_name='KDelPayload.key', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13,
  serialized_end=72,
)

DESCRIPTOR.message_types_by_name['KDelPayload'] = _KDELPAYLOAD

KDelPayload = _reflection.GeneratedProtocolMessageType('KDelPayload', (_message.Message,), dict(
  DESCRIPTOR = _KDELPAYLOAD,
  __module__ = 'msg_pb2'
  # @@protoc_insertion_point(class_scope:KDelPayload)
  ))
_sym_db.RegisterMessage(KDelPayload)


# @@protoc_insertion_point(module_scope)



from base64 import b64decode,b64encode

__all__ = [
    'decode',
    'encode'
]

def decode(msg,proto):
    try:
        proto.ParseFromString(b64decode(msg))
    except TypeError:
        return False
    except:
        raise
    return proto

def encode(proto):
    return b64encode(proto.SerializeToString())



from msg_pb2 import KDelPayload
from rask.base import Base
from rask.parser.pb import encode
from rask.rmq import BasicProperties

__all__ = ['Riak']

class Riak(Base):
    __channel_name = 'njord_riak_client'
    channel = None
    options = {
        'exchange':'njord_riak'
    }
    
    def __init__(self,rmq):
        self.ioengine.loop.add_callback(self.start,rmq)

    def kdel(self,cluster,bucket,key):
        try:
            assert self.active
        except AssertionError:
            self.log.debug('kdel - not active, promise added')
            self.promises.append(
                self.kdel,
                cluster=cluster,
                bucket=bucket,
                key=key
            )
        except:
            raise
        else:
            self.channel.basic_publish(
                exchange=self.options['exchange'],
                routing_key='',
                body=encode(KDelPayload(
                    cluster=cluster,
                    bucket=bucket,
                    key=key
                )),
                properties=BasicProperties(
                    headers={
                        'service':'kdel',
                        'cluster':cluster
                    }
                )
            )
        return True
   
    def kset(self,cluster,bucket,key,data,etag,content_type='application/json'):
        try:
            assert self.active
        except AssertionError:
            self.log.debug('kset - not active, promise added')
            self.promises.append(
                self.kset,
                cluster=cluster,
                bucket=bucket,
                key=key,
                data=data,
                etag=etag,
                content_type=content_type
            )
        except:
            raise
        else:
            self.channel.basic_publish(
                exchange=self.options['exchange'],
                routing_key='',
                body=encode(KSetPayload(
                    cluster=cluster,
                    bucket=bucket,
                    key=key,
                    data=data,
                    etag=etag,
                    content_type=content_type
                )),
                properties=BasicProperties(
                    headers={
                        'service':'kset',
                        'cluster':cluster
                    }
                )
            )
        return True
        
    def start(self,rmq):
        def on_channel(result):
            self.channel = result.result()
            self.active = True
            return True
        
        rmq.channel(self.__channel_name,future=self.ioengine.future(on_channel))
        return True
        
    def stop(self):
        self.channel.close()
        self.active = False
        return True



# -*- coding: utf-8 -*-
from bson import json_util
from simplejson import dumps,loads

__all__ = ['dictfy','jsonify']

def dictfy(_):
    try:
        return loads(_,object_hook=json_util.object_hook)
    except:
        return False

def jsonify(_):
    try:
        return dumps(_,default=json_util.default,separators=(',',':'))
    except:
        return False



from rask.base import Base
from rask.options import define,options,parse_command_line
from tornado.web import Application

__all__ = ['Main']

class Main(Base):
    __http__ = None
    __http_routes__ = []
    __options__ = {
        'http':{
            'port':8088
        },
        'rmq':{
            'channel':{
                'prefetch':10
            }
        }
    }
    
    def __init__(self):
        self.setup()
        self.before()
        self.ioengine.loop.add_callback(self.after)
        self.ioengine.loop.add_callback(self.http)
        self.ioengine.start()

    def after(self):
        pass
        
    def before(self):
        pass

    def http(self):
        try:
            assert self.__http_routes__
        except AssertionError:
            return False
        except:
            raise
        else:
            self.__http__ = Application(self.__http_routes__)
            self.ioengine.loop.add_callback(self.__http__.listen,options.rask['http']['port'])
            self.log.info('HTTP Server - %s' % options.rask['http']['port'])
        return True
    
    def setup(self):
        define('rask',default=self.__options__)
        parse_command_line()
        return True
